<?php
	/*
	 *		Modal Popup for Wizard Configuration
	 *
	 *	Sections for the following script:
	 *
	 *		1. INIT		: init the wizard_popup script loading class, variables and lang
	 *		2. FUNCTIONS	: functions used by the next sections
	 *		3. NETWORK	: configure and write the Network Settings string 
	 *		4. SCENARIOS	: configure and write the Scenarios string
	 * 		5. SIP_SECTION	: configure and write the Sip Settings string
	 * 		6. PRI_SECTION	: configure and write the Pri Settings string
	 * 		7. ACTIVATE	: summarize and activate the Settings
	 *
	 */

############################################### INIT #########################################
chdir("../..");
require_once ('./includes/session.php');

include ("./misc/database.php");
include ("./includes/variables.php");
include ("./misc/config_parameter.php");

$ba = new beroAri();

require_once ('./includes/lang.php');

######################################################## FUNCTIONS  #################################################################
function get_test_command_value ($cmd)
{
	exec($cmd, $output, $retval);
	return (($retval == 0) ? 1 : 0);
}

function display_internet_connection_message()
{
	//check internet connection
	$dns_on    = get_test_command_value('/bin/grep nameserver /etc/resolv.conf');
	$dns_works = get_test_command_value('/bin/ping -c 1 beronet.com');

	if (!($dns_on && $dns_works))
	{
		return WIZARD_NO_INTERNET_CONNECTION_DIS ."<br/>";
	}

	return '';
}

// Main displaying functions 
function display_modal_windows ($name, $title, $content, $nextmodal, $save_net, $error_message)
{
	ob_start();
?>
<p class='text-center h3' style='margin-top: 0px;'><?php echo $title; ?></p>
<form class='form-horizontal' method='POST' style='margin-top: 10px;' name='<?php echo $name; ?>' id='<?php echo $name; ?>form'>
	<input type='hidden' name='settings' value='<?php echo $nextmodal; ?>'>
	<div class='tab-content' style='border-top: 1px solid #ddd;'>
<?php 	echo (strlen($error_message) == 0 ? '' : "<div style='text-align: center; color: red;'>". $error_message . WIZARD_FIX_ERROR_MESSAGE_DIS ."</div>"); ?>
		<div role='tabpanel' class='tab-pane active' id='id<?php echo $name; ?>'>
<?php echo $content; ?>
		</div>
	</div>
</form>
<?php 
	$required_line = "<div class='text-center' style='margin: 10px;'><i>". REQUIRED_FIELDS ."</i></div>\n";
	if (strcmp($name, 'Scenarios') == 0)
	{
		$required_line = "<br/>\n";
	}
	else if (strcmp($name, 'Activate') == 0)
	{
		$required_line = "<div class='text-center' style='margin: 10px; color: red;'><i>". WIZARD_ACTIVATE_WARNING_DIS ."</i></div>\n";
	}

	return 	  ob_get_clean()
		. $required_line
		. display_bottom_buttons($name, $save_net, $error_message);
}

function display_general_javascript_code ($oldpage, $currentpage, $extra_code)
{
	ob_start();
?>
<script type="text/javascript">
<?php
	$html_str = ob_get_clean();

	if (strcmp($currentpage, 'Activate') == 0)
	{
		ob_start();
?>
	function activateWizard ()
	{
		session();

		var confirmMe = confirm('<?php echo WIZARD_ACTIVATE_CONFIRME_DIS; ?>');
		if (confirmMe)
		{
			window.location.href = "/app/berogui/modules/RebootReset/recreate.php?wizard=1";	
		}
	}
<?php
	}
	else
	{
		ob_start();
?>	
	function goToNextSettings ()
	{
		session();

		var checkForm = $("#<?php echo $currentpage; ?>form").validate({}).form();

		if (checkForm == true)
		{
<?php echo $extra_code; ?>
			$.ajax({
				type: 'POST',
				url: 'modules/Wizard/wizard_popup.php',
				data: $("#<?php echo $currentpage; ?>form").serialize(),
				success: function (loadedData) {
        	 			$('.modal-body').html(loadedData);
				},
				failure: function (errMsg) {
					alert(errMsg);
				}
			});
		}
	}
<?php
	}

	$html_str .= ob_get_clean() . "\n";	

	ob_start();
?>
	function goToPreviousSettings ()
	{
		session();

		$.ajax({
			type: 'POST',
			url: 'modules/Wizard/wizard_popup.php',
			data: {settings: '<?php echo $oldpage ?>', previous: 1},
			success: function (loadedData) {
               			$('.modal-body').html(loadedData);
			},
			failure: function (errMsg) {
				alert(errMsg);
			}
		});
	}

	$(document).ready(
		function () 
		{
			$('[data-toggle="tooltip"]').tooltip({placement: 'auto bottom', html: true, trigger: 'hover', contenter: 'body'});
		}
	);
</script>
<?php
	return $html_str . ob_get_clean() . "\n";
}

function display_bottom_buttons ($current_modal, $save_net, $error_message)
{
	$button_next 	= BUTTON_NEXT;
	$onclick_next 	= 'onclick="goToNextSettings();"';
	
	if (strcmp($current_modal, 'Activate') == 0)
	{
		$button_next	= BUTTON_ACTIVATE;
		$onclick_next	= 'onclick="activateWizard();"';
	}

	$button_previous = "\t<a role='button' class='btn btn-default' style='margin-right: 4px;' onclick=\"goToPreviousSettings();\">". BUTTON_PREVIOUS ."</a>\n";

	if (strcmp($current_modal, 'Network') == 0 || (strcmp($current_modal, 'Scenarios') == 0 && $save_net))
	{
		$button_previous = '';
	}	

	$html_str = 	  "<div class='text-center'>\n"
			. $button_previous
			. "\t<a role='button' data-remote='false' data-toggle='modal' data-target='#reset-popup' class='btn btn-default' style='margin-right: 4px;'>". BUTTON_CANCEL ."</a>\n"
			. (strlen($error_message) == 0 ? "\t<a role='button' class='btn btn-default' style='margin-right: 4px;' $onclick_next>$button_next</a>\n" : '')
			. "</div>\n\n";

	return $html_str;
}

function update_save_wizard_cfg($bool_previous, $save_setting, $configuration, $newparameters, $filename)
{
	unset($newparameters['previous']);

	// clean data from current modal
	if (isset($configuration[$save_setting]) && !($bool_previous))
	{
		unset($configuration[$save_setting]);
	}	

	// Update data 
	foreach ($newparameters as $parameter => $value)
	{
		if (is_array($value) || (is_string($value) && strlen($value) > 0))
		{
			$configuration[$save_setting][$parameter] = str_replace("]", "", str_replace("[", '', $value)); // TODO: figure out why a preg_replace does not working well
		}
	}

	// Save data
	$wizard_str = '';
	foreach ($configuration as $settings => $parameters)
	{
		$wizard_str .= '['. $settings ."]\n";
		foreach ($parameters as $parameter => $value)
		{
			if (is_array($value))
			{
				$wizard_str .= $parameter ."=". implode('-', $value) ."\n";
			} 
			else 
			{
				$wizard_str .= "$parameter=". $value ."\n";
			}
		}
		$wizard_str .= "\n";
	}

	$fp = fopen($filename, "w+");
	fputs($fp, html_entity_decode($wizard_str));
	fclose($fp);

	return $configuration;
}

######################################################## MAIN MODAL POPUP SECTION #################################################################
// init general variables
$previous_modal   = '';
$current_modal 	  = '';
$next_modal 	  = '';

$title_modal 	  = '';
$content_modal	  = '';

$javascript 	  = '';
$check_java_code  = '';

$flow_settings 	  = array(	'Network' 	=> array( 'previous' => 'Configuration'	, 'next' => 'Scenarios'	, 'title' => WIZARD_NETWORK_SETTINGS_DIS  ),
				'Scenarios' 	=> array( 'previous' => 'Network'	, 'next' => 'Sip'	, 'title' => WIZARD_SCENARIOS_SETTINGS_DIS),
				'Sip' 		=> array( 'previous' => 'Scenarios' 	, 'next' => 'Pstn'	, 'title' => WIZARD_SIP_SETTINGS_DIS	  ),
				'Pstn'		=> array( 'previous' => 'Sip'		, 'next' => 'Activate'	, 'title' => WIZARD_PSTN_SETTINGS_DIS	  ),
				'Activate'	=> array( 'previous' => 'Pstn'		, 'next' => ''		, 'title' => WIZARD_ACTIVATE_SETTINGS_DIS ));	

$wizard_cfg 	= array();
$filename 	= '/tmp/wizard.conf';

$error_message = display_internet_connection_message();

################## MODAL WINDOWS ###############

// get settings parameter
if (isset($_POST['settings']))
{
	$current_modal = $_POST['settings'];
	if (strcmp($_POST['settings'], 'Network') == 0 && strcmp($_POST['save_net'], 'true') == 0)
	{
		$current_modal = 'Scenarios';
	}

	$title_modal 	= $flow_settings[$current_modal]['title'];
	$previous_modal = $flow_settings[$current_modal]['previous'];
	$next_modal 	= $flow_settings[$current_modal]['next'];

	unset($_POST['settings']);
}

// load configuration file
if (file_exists($filename) && !(isset($_POST['init'])))
{
	$wizard_cfg = parse_ini_file($filename, true);
}
unset($_POST['init']);

// update and save the configurations
$wizard_cfg = update_save_wizard_cfg(isset($_POST['previous']) ? 1 : 0, $flow_settings[$current_modal]['previous'], $wizard_cfg, $_POST, $filename);

// update network saving boolean to show the right buttons
$save_net = false;
if (isset($wizard_cfg['Network']['save_net']))
{
	$save_net = true;
}

/* NETWORK - set Network Settings popup */
if (strcmp($current_modal, 'Network') == 0)
{
	$bc = new beroConf('root');
	if (!($bc -> valid()))
	{
		$error_message .= WIZARD_ERROR_DATABASE_DIS . "<br/>";
	}

	require_once('./modules/Wizard/network_wizard_popup.php');	
	$networkWizard = new NetworkWizard();

	$content_modal	= $networkWizard -> get_content_modal($bc, isset($wizard_cfg['Network']) ? $wizard_cfg['Network'] : array());

	$javascript 	 = $networkWizard -> get_javascript_code();
	$check_java_code = $networkWizard -> get_checking_javascript_code();
}

/* SCENARIOS - Set the VoIP Scenarios */
else if (strcmp($current_modal, 'Scenarios') == 0)
{
	require_once('./modules/Wizard/scenarios_wizard_popup.php');
	$scenariosWizard = new ScenariosWizard();

	$content_modal  = $scenariosWizard -> get_content_modal(isset($wizard_cfg['Scenarios']) ? $wizard_cfg['Scenarios'] : array());
}

/* SIP_SECTION - set Sip Settings popup */
else if (strcmp($current_modal, 'Sip') == 0)
{
	require_once('./modules/Wizard/sip_wizard_popup.php');
	$sipWizard = new SipWizard($wizard_cfg['Scenarios']['scenario']);

	$content_modal	= $sipWizard -> get_content_modal(isset($wizard_cfg['Sip']) ? $wizard_cfg['Sip'] : array(), $title_modal);

	$javascript 	 = $sipWizard -> get_javascript_code($current_modal . 'form');
	$check_java_code = $sipWizard -> get_checking_javascript_code();
}

/* PSTN_SECTION - set PTSN Settings popup */
else if (strcmp($current_modal, 'Pstn') == 0)
{
	require_once('./modules/Wizard/pstn_wizard_popup.php');
	$pstnWizard = new PstnWizard($wizard_cfg['Scenarios']['scenario']);

	$content_modal	= $pstnWizard -> get_content_modal(isset($wizard_cfg['Pstn']) ? $wizard_cfg['Pstn'] : array());

	$javascript 	 = $pstnWizard -> get_javascript_code($current_modal . 'form');
	$check_java_code = $pstnWizard -> get_checking_javascript_code();
}

/* ACTIVATE - Activate the Settings */
else if (strcmp($current_modal, 'Activate') == 0)
{
	require_once('./modules/Wizard/activate_wizard_popup.php');
	$activateWizard = new ActivateWizard($wizard_cfg);

	$content_modal = $activateWizard -> get_modal_content();
}

/* Wrong URL */
else 
{
	echo 'Wrong URL';
	return 0;
}

// display the modal content
$html_str .=	  display_general_javascript_code($previous_modal, $current_modal, $check_java_code)
		. display_modal_windows($current_modal, strtoupper($title_modal), $content_modal, $next_modal, $save_net, $error_message)
		. $javascript;

echo $html_str;

return 1;
?>
